@@ -5,9 +5,7 @@ This module provides a Loader class for locating and reading templates.
 
 """
 
-import os
 import platform
-import sys
 
 from pystache import common
 from pystache import defaults
@@ -17,6 +15,7 @@ from pystache.locator import Locator
 # We make a function so that the current defaults take effect.
 # TODO: revisit whether this is necessary.
 
+
 def _make_to_unicode():
     def to_unicode(s, encoding=None):
         """
@@ -26,6 +25,7 @@ def _make_to_unicode():
         if encoding is None:
             encoding = defaults.STRING_ENCODING
         return str(s, encoding, defaults.DECODE_ERRORS)
+
     return to_unicode
 
 
@@ -38,8 +38,13 @@ class Loader(object):
 
     """
 
-    def __init__(self, file_encoding=None, extension=None, to_unicode=None,
-                 search_dirs=None):
+    def __init__(
+        self,
+        file_encoding=None,
+        extension=None,
+        to_unicode=None,
+        search_dirs=None,
+    ):
         """
         Construct a template loader instance.
 
@@ -119,7 +124,7 @@ class Loader(object):
 
         if encoding is None:
             encoding = self.file_encoding
-        if platform.system() == "Windows":
+        if platform.system() == 'Windows':
             return self.str(b, encoding).replace('\r', '')
         return self.str(b, encoding)
 
