@@ -5,7 +5,6 @@ This module provides a Renderer class to render templates.
 
 """
 
-import sys
 
 from pystache import defaults
 from pystache.common import TemplateNotFoundError, MissingTags, is_string
@@ -47,9 +46,17 @@ class Renderer(object):
 
     """
 
-    def __init__(self, file_encoding=None, string_encoding=None,
-                 decode_errors=None, search_dirs=None, file_extension=None,
-                 escape=None, partials=None, missing_tags=None):
+    def __init__(
+        self,
+        file_encoding=None,
+        string_encoding=None,
+        decode_errors=None,
+        search_dirs=None,
+        file_extension=None,
+        escape=None,
+        partials=None,
+        missing_tags=None,
+    ):
         """
         Construct an instance.
 
@@ -229,8 +236,12 @@ class Renderer(object):
         Create a Loader instance using current attributes.
 
         """
-        return Loader(file_encoding=self.file_encoding, extension=self.file_extension,
-                      to_unicode=self.str, search_dirs=self.search_dirs)
+        return Loader(
+            file_encoding=self.file_encoding,
+            extension=self.file_extension,
+            to_unicode=self.str,
+            search_dirs=self.search_dirs,
+        )
 
     def _make_load_template(self):
         """
@@ -262,8 +273,9 @@ class Renderer(object):
             #   raise a KeyError on name not found.
             template = partials.get(name)
             if template is None:
-                raise TemplateNotFoundError("Name %s not found in partials: %s" %
-                                            (repr(name), type(partials)))
+                raise TemplateNotFoundError(
+                    'Name %s not found in partials: %s' % (repr(name), type(partials))
+                )
 
             # RenderEngine requires that the return value be unicode.
             return self._to_unicode_hard(template)
@@ -328,11 +340,13 @@ class Renderer(object):
         resolve_context = self._make_resolve_context()
         resolve_partial = self._make_resolve_partial()
 
-        engine = RenderEngine(literal=self._to_unicode_hard,
-                              escape=self._escape_to_unicode,
-                              resolve_context=resolve_context,
-                              resolve_partial=resolve_partial,
-                              to_str=self.str_coerce)
+        engine = RenderEngine(
+            literal=self._to_unicode_hard,
+            escape=self._escape_to_unicode,
+            resolve_context=resolve_context,
+            resolve_partial=resolve_partial,
+            to_str=self.str_coerce,
+        )
         return engine
 
     # TODO: add unit tests for this method.
@@ -397,7 +411,7 @@ class Renderer(object):
         # RenderEngine.render() requires that the template string be unicode.
         template = self._to_unicode_hard(template)
 
-        render_func = lambda engine, stack: engine.render(template, stack)
+        render_func = lambda engine, stack: engine.render(template, stack)  # noqa
 
         return self._render_final(render_func, *context, **kwargs)
 
@@ -453,7 +467,7 @@ class Renderer(object):
         if is_string(template):
             return self._render_string(template, *context, **kwargs)
         if isinstance(template, ParsedTemplate):
-            render_func = lambda engine, stack: template.render(engine, stack)
+            render_func = lambda engine, stack: template.render(engine, stack)  # noqa
             return self._render_final(render_func, *context, **kwargs)
         # Otherwise, we assume the template is an object.
 
